changeset 22358:6c112ffbcc91

Clean up mechanism for removing -l loadup from end.
author Karl Heuer <kwzh@gnu.org>
date Fri, 05 Jun 1998 15:49:43 +0000
parents e354812f332e
children 9e5f3f1c0c0f
files lisp/loadup.el
diffstat 1 files changed, 6 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/loadup.el	Fri Jun 05 15:48:37 1998 +0000
+++ b/lisp/loadup.el	Fri Jun 05 15:49:43 1998 +0000
@@ -251,13 +251,12 @@
 
 ;; For machines with CANNOT_DUMP defined in config.h,
 ;; this file must be loaded each time Emacs is run.
 ;; So run the startup code now.
 
-(or (equal (nth 3 command-line-args) "dump")
-    (equal (nth 4 command-line-args) "dump")
-    (progn
-      ;; Avoid loading loadup.el a second time!
-      (setq command-line-args (cdr (cdr command-line-args)))
-      (eval top-level)))
+(if (and (equal (nth 1 command-line-args) "-l")
+	 (equal (nth 2 command-line-args) "loadup"))
+    (setcdr command-line-args (nthcdr 3 command-line-args)))
+
+(eval top-level)
 
 ;;; loadup.el ends here
@@ -251,13 +251,12 @@
 ;; For machines with CANNOT_DUMP defined in config.h,
 ;; this file must be loaded each time Emacs is run.
-;; So run the startup code now.
+;; So run the startup code now.  First, remove `-l loadup' from args.
 